@@ -7,11 +7,11 @@
 # by Markus Loecher, Sense Networks <markus at sensenetworks.com>
 
 # October 2012
-# Updated with contributions by Sbastien Rochette
+# Updated with contributions by Sebastien Rochette
 
 gmap <- function(x, exp=1, type='terrain', filename='', style=NULL, scale=1, zoom=NULL, size=c(640, 640), rgb=FALSE, lonlat=FALSE, ...) {
 
-	if (! require(rgdal) ) { 
+	if (! requireNamespace('rgdal') ) { 
 		stop('rgdal not available') 
 	}
 	
@@ -78,8 +78,8 @@ gmap <- function(x, exp=1, type='terrain', filename='', style=NULL, scale=1, zoo
 	
 	if (is.character(x)) {
 		x <- geocode(x, oneRecord=TRUE)
-		if (any(is.na(x))) {
-			stop('location not found')
+		if (is.na(x$latitude)) { 
+			stop('location not found') 
 		}
 		x <- extent(as.vector(as.matrix(x[5:8])))
 
