@@ -5,9 +5,10 @@
 # Licence GPL v3
 
 
-nicheOverlap <- function (x, y, mask=TRUE, checkNegatives=TRUE) {
+nicheOverlap <- function (x, y, stat='I', mask=TRUE, checkNegatives=TRUE) {
 	s <- stack(x, y)
 
+	stopifnot(stat %in% c('I', 'D'))
 	# to assure that both have the same NA cells
 	if (mask) {
 		s <- mask(s,  x * y)
@@ -20,8 +21,17 @@ nicheOverlap <- function (x, y, mask=TRUE, checkNegatives=TRUE) {
 		}
 	}
 	
-    cs <- cellStats(s, 'sum', na.rm=TRUE)
-	r <- overlay(s, fun=function(i,j) (sqrt(i / cs[1]) - sqrt(j / cs[2] ))^2)
-	1 - 0.5 * sqrt(cellStats(r, 'sum', na.rm=TRUE))
+	cs <- cellStats(s, 'sum', na.rm=TRUE)
+	if (stat == 'I') {
+		r <- overlay(s, fun=function(i,j) (sqrt(i / cs[1]) - sqrt(j / cs[2] ))^2)
+		H2 <- cellStats(r, 'sum', na.rm=TRUE)
+		1 - 0.5 * H2
+	} else {
+		r <- overlay(s, fun=function(i,j) abs((i / cs[1]) - (j / cs[2])))
+		D <- cellStats(r, 'sum', na.rm=TRUE)
+		1 - 0.5 * D
+	
+	}
 }
 
+
